/**
 * Copyright (c) 2023 Vitor Pamplona
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
 * Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.vitorpamplona.amethyst.ui.note

import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Divider
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import com.vitorpamplona.amethyst.model.User
import com.vitorpamplona.amethyst.ui.screen.loggedIn.AccountViewModel
import com.vitorpamplona.amethyst.ui.theme.DividerThickness
import com.vitorpamplona.amethyst.ui.theme.Size55dp
import com.vitorpamplona.amethyst.ui.theme.StdPadding

@Composable
fun UserCompose(
    baseUser: User,
    overallModifier: Modifier = StdPadding,
    showDiviser: Boolean = true,
    accountViewModel: AccountViewModel,
    nav: (String) -> Unit,
) {
    Column(
        modifier =
            Modifier.clickable(
                onClick = { nav("User/${baseUser.pubkeyHex}") },
            ),
    ) {
        Row(
            modifier = overallModifier,
            verticalAlignment = Alignment.CenterVertically,
        ) {
            UserPicture(baseUser, Size55dp, accountViewModel = accountViewModel, nav = nav)

            Column(modifier = remember { Modifier.padding(start = 10.dp).weight(1f) }) {
                Row(verticalAlignment = Alignment.CenterVertically) { UsernameDisplay(baseUser) }

                AboutDisplay(baseUser)
            }

            Column(modifier = remember { Modifier.padding(start = 10.dp) }) {
                UserActionOptions(baseUser, accountViewModel)
            }
        }

        if (showDiviser) {
            Divider(
                thickness = DividerThickness,
            )
        }
    }
}
