/**
 * Copyright (c) 2023 Vitor Pamplona
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
 * Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.vitorpamplona.quartz.encoders

import android.util.Log
import java.util.regex.Pattern

val lnurlpPattern = Pattern.compile("(?i:http|https):\\/\\/((.+)\\/)*\\.well-known\\/lnurlp\\/(.*)")

class Lud06 {
    fun toLud16(str: String): String? {
        return try {
            val url = toLnUrlp(str)

            val matcher = lnurlpPattern.matcher(url)
            matcher.find()
            val domain = matcher.group(2)
            val username = matcher.group(3)

            "$username@$domain"
        } catch (t: Throwable) {
            t.printStackTrace()
            Log.w("Lud06ToLud16", "Fail to convert LUD06 to LUD16", t)
            null
        }
    }

    fun toLnUrlp(str: String): String? {
        return try {
            String(Bech32.decodeBytes(str, false).second)
        } catch (t: Throwable) {
            t.printStackTrace()
            Log.w("Lud06ToLud16", "Fail to convert LUD06 to LUD16", t)
            null
        }
    }
}
